@@ -6,16 +6,17 @@ cor.with.limit <- function(limit, x, y) {
     n.x <- ncol(x) # caller makes sure that n.x
     n.y <- ncol(y) # and n.y >= 1
     r.mat <- matrix(NA_real_, n.x, n.y)
-    for(i in seq_len(n.x)){
+    for (i in seq_len(n.x)) {
         this.x <- x[, i]
         good.x <- !is.na(this.x)
-        for(j in seq_len(n.y)){
+        for (j in seq_len(n.y)) {
             this.y <- y[, j]
             good.y <- !is.na(this.y)
             good.both <- which(good.x & good.y)
             n.good <- length(good.both)
-            if(n.good >= limit && n.good > 0)
+            if (n.good >= limit && n.good > 0) {
                 r.mat[i, j] <- cor(this.x[good.both], this.y[good.both])
+            }
         }
     }
     r.mat
@@ -27,18 +28,28 @@ cor.with.limit.upper <- function(limit, x) {
     r.vec <- rep(NA_real_, n.x * (n.x - 1) / 2)
     good.x <- !is.na(x)
     k <- 0
-    for(i in seq_len(n.x - 1)){
+    for (i in seq_len(n.x - 1)) {
         good.i <- good.x[, i]
-        for(j in (i + 1):n.x){
+        for (j in (i + 1):n.x) {
             k <- k + 1
             good.both <- which(good.i & good.x[, j])
-            if(length(good.both) >= limit)
+            if (length(good.both) >= limit) {
                 r.vec[k] <- cor(x[good.both, i], x[good.both, j])
+            }
         }
     }
     r.vec
 }
 
+rwi.stats <- function(rwi, ids=NULL, period=c("max", "common"), ...) {
+    args <- list(...)
+    args[["rwi"]] <- rwi
+    args[["ids"]] <- ids
+    args[["period"]] <- period
+    args[["running.window"]] <- FALSE
+    do.call(rwi.stats.running, args)
+}
+
 ### Main function, exported to user
 rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
                               running.window=TRUE,
@@ -47,26 +58,29 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
                               first.start=NULL,
                               min.corr.overlap=min(30, window.length),
                               round.decimals=3,
-                              zero.is.missing=FALSE){
+                              zero.is.missing=TRUE) {
     period2 <- match.arg(period)
 
-    if(running.window){
-        if(window.length < 3)
+    if (running.window) {
+        if (window.length < 3) {
             stop("minimum 'window.length' is 3")
+        }
         window.advance <- window.length - window.overlap
-        if(window.advance < 1)
+        if (window.advance < 1) {
             stop(gettextf("'window.overlap' is too large, max value is 'window.length'-1 (%d)",
                           window.length - 1))
-        if(window.length < min.corr.overlap)
+        }
+        if (window.length < min.corr.overlap) {
             stop("'window.length' is smaller than 'min.corr.overlap'")
+        }
     }
 
     rwi2 <- as.matrix(rwi)
     n.cores <- ncol(rwi2)
 
     zero.flag <- rwi2 == 0
-    if(any(zero.flag, na.rm=TRUE)) {
-        if(!zero.is.missing) {
+    if (any(zero.flag, na.rm=TRUE)) {
+        if (!zero.is.missing) {
             warning("There are zeros in the data. Consider the option 'zero.is.missing'.")
         } else {
             rwi2[zero.flag] <- NA
@@ -74,34 +88,38 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
     }
 
     ## If 'ids' is NULL then assume one core per tree
-    if(is.null(ids)){
+    if (is.null(ids)) {
         ids3 <- data.frame(tree=seq_len(n.cores), core=rep(1, n.cores))
         rwi3 <- rwi2
-    } else{
+    } else {
         ## Make error checks here
-        if(!is.data.frame(ids) || !all(c("tree", "core") %in% names(ids)))
+        if (!is.data.frame(ids) || !all(c("tree", "core") %in% names(ids))) {
             stop("'ids' must be a data.frame with columns 'tree' and 'core'")
-        if(nrow(ids) != n.cores)
-            stop("dimension problem: ", "'ncol(rwi)' != 'nrow(ids)'")
-        if(!all(vapply(ids, is.numeric, TRUE)))
+        }
+        if (!all(vapply(ids, is.numeric, TRUE))) {
             stop("'ids' must have numeric columns")
+        }
         colnames.rwi <- colnames(rwi2)
-        ## If the set of row names in 'ids' is the same as the set of
-        ## column names in 'rwi', arrange 'ids' to matching order
-        if(all(row.names(ids) %in% colnames.rwi))
+        ## If all column names in 'rwi' are present in the set of row
+        ## names in 'ids', arrange 'ids' to matching order
+        rownames.ids <- row.names(ids)
+        if (!is.null(rownames.ids) && all(colnames.rwi %in% rownames.ids)) {
             ids2 <- ids[colnames.rwi, c("tree", "core")]
-        else
+        } else if (nrow(ids) == n.cores) {
             ids2 <- ids[c("tree", "core")]
+        } else {
+            stop("dimension problem: ", "'ncol(rwi)' != 'nrow(ids)'")
+        }
         row.names(ids2) <- NULL
         unique.ids <- unique(ids2)
         n.unique <- nrow(unique.ids)
-        if(n.unique < n.cores) {
+        if (n.unique < n.cores) {
             ## If more than one columns of 'rwi' share a tree/core ID pair,
             ## the columns are averaged and treated as one core
             ids3 <- unique.ids
             rwi3 <- matrix(data=as.numeric(NA), nrow=nrow(rwi2), ncol=n.unique,
                            dimnames=list(rownames(rwi2)))
-            for(i in seq_len(n.unique)) {
+            for (i in seq_len(n.unique)) {
                 these.cols <- row.match(ids2, unique.ids[i, ])
                 rwi3[, i] <-
                     rowMeans(rwi2[, these.cols, drop=FALSE], na.rm=TRUE)
@@ -114,45 +132,52 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
     }
 
     n.years <- nrow(rwi3)
-    if(running.window && window.length > n.years)
+    if (running.window && window.length > n.years) {
         stop("'window.length' is larger than the number of years in 'rwi'")
+    }
 
     unique.trees <- unique(ids3$tree)
     n.trees <- length(unique.trees)
-    if(n.trees < 2) stop("at least 2 trees are needed")
+    if (n.trees < 2) {
+        stop("at least 2 trees are needed")
+    }
     cores.of.tree <- list()
     seq.tree <- seq_len(n.trees)
-    for(i in seq.tree)
+    for (i in seq.tree) {
         cores.of.tree[[i]] <- which(ids3$tree==unique.trees[i])
+    }
 
     ## n.trees.by.year is recorded before setting rows with missing
     ## data to NA
     tree.any <- matrix(FALSE, n.years, n.trees)
-    for(i in seq.tree)
+    for (i in seq.tree) {
         tree.any[, i] <-
             apply(!is.na(rwi3[, ids3$tree == unique.trees[i], drop=FALSE]),
                   1, any)
+    }
     n.trees.by.year <- rowSums(tree.any)
     good.rows <- which(n.trees.by.year > 1)
 
     ## Easy way to force complete overlap of data
-    if(period2 == "common"){
+    if (period2 == "common") {
         bad.rows <- which(apply(is.na(rwi3), 1, any))
         rwi3[bad.rows, ] <- NA
         good.rows <- setdiff(good.rows, bad.rows)
     }
 
-    if(length(good.rows) < min.corr.overlap)
+    if (length(good.rows) < min.corr.overlap) {
         stop("too few years with enough trees for correlation calculations")
+    }
 
-    if(running.window){
-        if(is.numeric(first.start)){
-            if(first.start < 1)
+    if (running.window) {
+        if (is.numeric(first.start)) {
+            if (first.start < 1) {
                 stop("'first.start' too small, must be >= 1")
-            else if(first.start > n.years - window.length + 1)
+            } else if (first.start > n.years - window.length + 1) {
                 stop("'first.start' too large")
+            }
             first.start2 <- first.start
-        } else{
+        } else {
             ## Select locations of running windows by maximizing the
             ## number of data points (sum of number of series for each
             ## selected year), but don't count rows with less than two
@@ -164,14 +189,14 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
             offsets <- min.offset:max.offset
             n.offsets <- length(offsets)
             n.data <- rep(NA_real_, n.offsets)
-            for(i in seq_len(n.offsets)){
+            for (i in seq_len(n.offsets)) {
                 offset <- offsets[i]
                 n.windows.minusone <-
                     (n.years - offset - window.length) %/% window.advance
                 max.idx <-
                     offset + window.length + n.windows.minusone * window.advance
                 n.data[i] <- sum(!is.na(rwi3[intersect(good.rows,
-                                                      (1 + offset):max.idx), ]))
+                                                       (1 + offset):max.idx), ]))
             }
             ## In case of a tie, choose large offset.
             ## In practice, this prefers recent years.
@@ -182,14 +207,14 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
                             to = n.years - window.length + 1,
                             by = window.advance)
         window.length2 <- window.length
-    } else{
+    } else {
         window.start <- 1
         window.length2 <- n.years
     }
 
     all.years <- as.numeric(rownames(rwi3))
 
-    loop.body <- function(s.idx){
+    loop.body <- function(s.idx) {
         rbar.tot <- NA_real_
         rbar.wt <- NA_real_
         rbar.bt <- NA_real_
@@ -206,15 +231,15 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         rsum.bt <- 0
         n.bt <- 0
         good.flag <- rep(FALSE, n.trees)
-        for(i in seq_len(n.trees - 1)){
+        for (i in seq_len(n.trees - 1)) {
             i.data <- rwi3[year.idx, cores.of.tree[[i]], drop=FALSE]
-            for(j in (i + 1):n.trees){
+            for (j in (i + 1):n.trees) {
                 j.data <- rwi3[year.idx, cores.of.tree[[j]], drop=FALSE]
                 bt.r.mat <- dplR:::cor.with.limit(min.corr.overlap,
                                                   i.data, j.data)
                 bt.r.mat <- bt.r.mat[!is.na(bt.r.mat)]
                 n.bt.temp <- length(bt.r.mat)
-                if(n.bt.temp > 0){
+                if (n.bt.temp > 0) {
                     rsum.bt <- rsum.bt + sum(bt.r.mat)
                     n.bt <- n.bt + n.bt.temp
                     good.flag[c(i, j)] <- TRUE
@@ -227,9 +252,9 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         rsum.wt <- 0
         n.wt <- 0
         n.cores.tree <- rep(NA_real_, n.trees)
-        for(i in good.trees){
+        for (i in good.trees) {
             these.cores <- cores.of.tree[[i]]
-            if(length(these.cores)==1){ # make simple case fast
+            if (length(these.cores)==1) { # make simple case fast
                 n.cores.tree[i] <- 1
             } else {
                 these.data <- rwi3[year.idx, these.cores, drop=FALSE]
@@ -237,7 +262,7 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
                     dplR:::cor.with.limit.upper(min.corr.overlap, these.data)
                 wt.r.vec <- wt.r.vec[!is.na(wt.r.vec)]
                 n.wt.temp <- length(wt.r.vec)
-                if(n.wt.temp > 0){
+                if (n.wt.temp > 0) {
                     rsum.wt <- rsum.wt + sum(wt.r.vec)
                     n.wt <- n.wt + n.wt.temp
                     ## Solving c (> 0) in the formula n = 0.5 * c * (c-1)
@@ -251,12 +276,15 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
 
         ## Mean correlations
         n.tot <- n.wt + n.bt
-        if(n.tot > 0)
+        if (n.tot > 0) {
             rbar.tot <- (rsum.wt + rsum.bt) / n.tot
-        if(n.wt > 0)
+        }
+        if (n.wt > 0) {
             rbar.wt <- rsum.wt / n.wt
-        if(n.bt > 0)
+        }
+        if (n.bt > 0) {
             rbar.bt <- rsum.bt / n.bt
+        }
 
         ## Number of trees averaged over the years in the window.
         ## We keep this number separate of the correlation estimates,
@@ -265,10 +293,10 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         n <- mean(n.trees.by.year[year.idx], na.rm=TRUE)
 
         ## Expressed population signal
-        if(n.wt == 0){
+        if (n.wt == 0) {
             c.eff <- 1
             rbar.eff <- rbar.bt
-        } else{
+        } else {
             c.eff.rproc <- mean(1 / n.cores.tree, na.rm=TRUE)
             c.eff <- 1 / c.eff.rproc # bookkeeping only
             rbar.eff <- rbar.bt / (rbar.wt + (1 - rbar.wt) * c.eff.rproc)
@@ -277,12 +305,12 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
         ## In our interpretation of EPS, we use the average number of trees.
         eps <- n * rbar.eff / ((n - 1) * rbar.eff + 1)
 
-        if(running.window){
+        if (running.window) {
             c(start.year = start.year, mid.year = mid.year, end.year = end.year,
               n.tot = n.tot, n.wt = n.wt, n.bt = n.bt, rbar.tot = rbar.tot,
               rbar.wt = rbar.wt, rbar.bt = rbar.bt, c.eff = c.eff,
               rbar.eff = rbar.eff, eps = eps, n = n)
-        } else{
+        } else {
             c(n.tot = n.tot, n.wt = n.wt, n.bt = n.bt, rbar.tot = rbar.tot,
               rbar.wt = rbar.wt, rbar.bt = rbar.bt, c.eff = c.eff,
               rbar.eff = rbar.eff, eps = eps, n = n)
@@ -290,26 +318,28 @@ rwi.stats.running <- function(rwi, ids=NULL, period=c("max", "common"),
     }
 
     ## Iterate over all windows
-    if(!inherits(try(suppressWarnings(req.fe <-
-                                      require(foreach, quietly=TRUE)),
-                     silent = TRUE),
-                 "try-error") && req.fe){
+    if (running.window &&
+        !inherits(try(suppressWarnings(req.fe <-
+                                       require(foreach, quietly=TRUE)),
+                      silent = TRUE),
+                  "try-error") && req.fe) {
         compos.stats <-
             foreach(s.idx=window.start, .combine="rbind",
                     .packages="dplR") %dopar% {
-                loop.body(s.idx)
-            }
-    } else{
+                        loop.body(s.idx)
+                    }
+    } else {
         compos.stats <- NULL
-        for(s.idx in window.start)
+        for (s.idx in window.start) {
             compos.stats <- rbind(compos.stats, loop.body(s.idx))
+        }
     }
 
-    if(!running.window)
-        compos.stats <- rbind(compos.stats)
     rownames(compos.stats) <- NULL
-    if(is.numeric(round.decimals) && round.decimals >= 0)
-        data.frame(round(compos.stats, round.decimals))
-    else
+    if (is.numeric(round.decimals) && length(round.decimals) > 0 &&
+        is.finite(round.decimals[1]) && round.decimals[1] >= 0) {
+        data.frame(round(compos.stats, round.decimals[1]))
+    } else {
         data.frame(compos.stats)
+    }
 }
